-- version 2.21
-- date 08.07.2013

-- default options
LowHPAlert_Options = {
    ["tankmode"] = false,
    ["soundcombatonly"] = false,
    ["soundalwaysoff"] = false,
	["cockpit"] = false,
    ["version"] = "2.2",
};
local sounds = true;

-- sets player HP to OK!
local LastHealth = 0;

-- event caller
function LowHPAlert_OnUpdate()
	if (LowHPAlert_Options.soundalwaysoff) then
		sounds = false;
	elseif (LowHPAlert_Options.soundcombatonly and not UnitAffectingCombat("player")) then
		sounds = false;
	else
		sounds = true;
	end
	
	-- some hardcore math
	hp = UnitHealth("player");
	hpPct = hp / UnitHealthMax("player");
	
	if (LowHPAlert_Options.tankmode) then
		LowHPAlert_OnUpdate_tank();
	elseif (LowHPAlert_Options.cockpit) then
		LowHPAlert_OnUpdate_cockpit();
	else
		LowHPAlert_OnUpdate_default();
	end	
end

-- tankmode 0 = warning at 50% and 25%
function LowHPAlert_OnUpdate_default()
    if (hpPct > 0.5) then
    	LastHealth = 0;
		return;
    end

    if (hpPct > 0.25) then
    	if (LastHealth == 0) then
			HealthMessageFrame:AddMessage("HP < 50%", 1, 1, 0, 1, 3);
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\50.ogg", "master") end
		end
    	LastHealth = 1;
		return;
    end

    -- HP < 25%
    if (LastHealth ~= 2) then
    	HealthMessageFrame:AddMessage("WARNING\nHP < 25%", 1, 0, 0, 1, 3);
		if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\20.ogg", "master") end
	end
	LastHealth = 2;
end

-- tankmode 1 = warning at 30%
function LowHPAlert_OnUpdate_tank()
	-- 30%
	if (hpPct > 0.3) then
    	LastHealth = 0;
	return;
    end

	-- HP <= 30%
    if (hpPct <= 0.3) then
    	if (LastHealth == 0) then
			HealthMessageFrame:AddMessage("WARNING\nHP < 30%", 1, 0, 0, 1, 3);
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\30.ogg", "master") end
		end
		LastHealth = 1;
		return;
    end
end

-- cockpit mode
-- spams 50 - 40 - 30 - 20 - 10 - retard
function LowHPAlert_OnUpdate_cockpit()
    if (hpPct > 0.5) then
    	LastHealth = 0;
		return;
    end
	
	-- 50% - 40%
    if (hpPct > 0.4) then
    	if (LastHealth == 0) then
			HealthMessageFrame:AddMessage("HP < 50%", 1, 1, 0, 1, 3);
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\50.ogg", "master") end
		end
    	LastHealth = 5;
		return;
    end
	
	-- 40% - 30%
    if (hpPct > 0.3) then
    	if (LastHealth > 4 or LastHealth == 0) then
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\cockpit\\40.ogg", "master") end
		end
    	LastHealth = 4;
		return;
    end
	
	-- 30% - 20%
    if (hpPct > 0.2) then
    	if (LastHealth > 3 or LastHealth == 0) then
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\cockpit\\30.ogg", "master") end
		end
    	LastHealth = 3;
		return;
    end

	-- 20% - 10%
    if (hpPct > 0.1) then
    	if (LastHealth > 2 or LastHealth == 0) then
			HealthMessageFrame:AddMessage("WARNING\nHP < 20%", 1, 0, 0, 1, 3);
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\20.ogg", "master") end
		end
    	LastHealth = 2;
		return;
    end
		
	-- HP <= 10%
    if (hpPct <= 0.1 and UnitIsDead("player") ~= 1) then
    	if (LastHealth ~= -2) then
			HealthMessageFrame:AddMessage("OMG! OMG! OMG!", 1, 0, 0, 1, 3);
			if (sounds) then PlaySoundFile("Interface\\AddOns\\LowHPAlert\\cockpit\\retard.ogg", "master") end
		end
		LastHealth = -2;
		return;
    end
end

-- slash commands
SLASH_LOWHPALERT1 = '/lowhpalert';
local function slashhandler(msg, editbox)
	if msg == 'tankmode' then
		if(LowHPAlert_Options.tankmode) then
			LowHPAlert_Options.tankmode = false;
			print("Tankmode OFF!");
		else
			LowHPAlert_Options.tankmode = true;
			print("Tankmode ON!");
		end
	elseif msg == 'combatmode' then
		if(LowHPAlert_Options.soundcombatonly) then
			LowHPAlert_Options.soundcombatonly = false;
			print("Sounds always ON!");
		else
			LowHPAlert_Options.soundcombatonly = true;
			print("Sounds will be only played in combat!");
		end
	elseif msg == 'sound' then
		if(LowHPAlert_Options.soundalwaysoff) then
			LowHPAlert_Options.soundalwaysoff = false;
			print("Sounds ON!");
		else
			LowHPAlert_Options.soundalwaysoff = true;
			print("Sounds always OFF!");
		end
	elseif msg == 'cockpit' then
		if(LowHPAlert_Options.cockpit) then
			LowHPAlert_Options.cockpit = false;
			print("Cockpit mode OFF!");
		else
			LowHPAlert_Options.cockpit = true;
			print("Cockpit mode ON! HAVE FUN DYING :)");
		end
	else
		print(" ");
		print("LowHPAlert version " .. LowHPAlert_Options.version);
		print("-----------------------------");
		print("/lowhpalert tankmode - only alerts at 30% HP (good for tanking)");
		print("/lowhpalert combatmode - only play alert sounds in combat");
		print("/lowhpalert sound - turn off all sounds");
		print("/lowhpalert cockpit - cockpit mode! feel like landing an airbus (fun!) :)");
	end
end
SlashCmdList["LOWHPALERT"] = slashhandler;

function LowHPAlert_OnLoad()
	DEFAULT_CHAT_FRAME:AddMessage("Low HP Alert version " .. LowHPAlert_Options.version .. " loaded - Options: /lowhpalert", 0.0, 0.8, 0.0, nil, true);
end